<h1 align="center">Box</h1>
<p align="center">Fast and simple file versioning</p>

<p align="center">
    <a href="https://github.com/firlast/box/releases">
        <img alt="GitHub release (latest by date including pre-releases)" src="https://img.shields.io/github/v/release/firlast/box?include_prereleases">
    </a>
    <a href="https://github.com/firlast/box/blob/master/LICENSE" style="margin-right: 5px; margin-left: 5px">
        <img alt="PyPI - License" src="https://img.shields.io/pypi/l/box">
    </a>
</p>

Box is an open-source version control system **written in Python** that allows users to manage changes to their projects efficiently and collaboratively. With Box, you can control the history of **changes made to files**, track issues and bugs, and collaborate with other developers in a safe and secure environment. With an **intuitive interface** and customizable features, Box is a complete solution for development teams looking for an affordable and easy-to-use version control system. If you are looking for an efficient and organized way to manage your project versions, Box is a smart and affordable choice.

## Getting Started with Box

Installing Box using PIP from PyPI package manager:

```
pip install box-vcs
```

Or you can install Box version control cloning the official repository of the project and perform the manual installation by running the `setup.py` script. Here:

```
git clone https://github.com/firlast/box.git
cd box/
python3 setup.py install
```

### Links

- [Official project documentation](https://github.com/firlast/box/tree/master/docs)
- [GitHub Releases](https://github.com/firlast/box/releases)
- [PyPI project](https://pypi.org/project/box-vcs)

## License

```text
GNU General Public License v2.0
Copyright (C) 2023  Firlast
```

This project uses the [GPL-2.0 License](https://github.com/firlast/box/blob/master/LICENSE), please see the license file to more information.